@@ -56,7 +56,6 @@ KompareShell::KompareShell()
 	m_textViewWidget( 0 ),
 	m_eventLoopLocker( new QEventLoopLocker() )
 {
-	if ( !initialGeometrySet() )
 	resize( 800, 480 );
 
 	// set the shell's ui resource file
@@ -475,5 +474,3 @@ KompareInterface* KompareShell::viewPart() const
 {
 	return qobject_cast<KompareInterface *>(m_viewPart);
 }
-
-#include "kompare_shell.moc"
